# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/tarot/users.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17tarot/tarot/users.proto\x12\x05tarot\"\xa6\x01\n\x0cTelegramUser\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x12\n\nfirst_name\x18\x04 \x01(\t\x12\x11\n\tlast_name\x18\x05 \x01(\t\x12\x15\n\rlanguage_code\x18\x06 \x01(\t\x12\x0e\n\x06is_bot\x18\x07 \x01(\x08\x12\x12\n\nis_premium\x18\x08 \x01(\x08\x12\x16\n\x0eprofile_photos\x18\t \x03(\t\"\xb0\x01\n\rSpreadProfile\x12\r\n\x05tg_id\x18\x01 \x01(\x05\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\x12\n\nbirth_date\x18\x03 \x01(\t\x12\x12\n\nbirth_time\x18\x04 \x01(\t\x12\x13\n\x0b\x62irth_place\x18\x05 \x01(\t\x12\x13\n\x0bzodiac_sign\x18\x06 \x01(\t\x12\x1b\n\x13\x63hinese_zodiac_sign\x18\x07 \x01(\t\x12\x0e\n\x06gender\x18\x08 \x01(\t\"!\n\x13TelegramUserRequest\x12\n\n\x02id\x18\x02 \x01(\x05\x32\x8e\x02\n\x05Users\x12>\n\x12\x43reateTelegramUser\x12\x13.tarot.TelegramUser\x1a\x13.tarot.TelegramUser\x12\x42\n\x0fGetTelegramUser\x12\x1a.tarot.TelegramUserRequest\x1a\x13.tarot.TelegramUser\x12>\n\x12UpdateTelegramUser\x12\x13.tarot.TelegramUser\x1a\x13.tarot.TelegramUser\x12\x41\n\x13UpdateSpreadProfile\x12\x14.tarot.SpreadProfile\x1a\x14.tarot.SpreadProfileb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.tarot.users_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TELEGRAMUSER']._serialized_start=35
  _globals['_TELEGRAMUSER']._serialized_end=201
  _globals['_SPREADPROFILE']._serialized_start=204
  _globals['_SPREADPROFILE']._serialized_end=380
  _globals['_TELEGRAMUSERREQUEST']._serialized_start=382
  _globals['_TELEGRAMUSERREQUEST']._serialized_end=415
  _globals['_USERS']._serialized_start=418
  _globals['_USERS']._serialized_end=688
# @@protoc_insertion_point(module_scope)
