# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from tarot.tarot import users_pb2 as tarot_dot_tarot_dot_users__pb2


class UsersStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTelegramUser = channel.unary_unary(
                '/tarot.Users/CreateTelegramUser',
                request_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
                response_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
                )
        self.GetTelegramUser = channel.unary_unary(
                '/tarot.Users/GetTelegramUser',
                request_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUserRequest.SerializeToString,
                response_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
                )
        self.UpdateTelegramUser = channel.unary_unary(
                '/tarot.Users/UpdateTelegramUser',
                request_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
                response_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
                )
        self.UpdateSpreadProfile = channel.unary_unary(
                '/tarot.Users/UpdateSpreadProfile',
                request_serializer=tarot_dot_tarot_dot_users__pb2.SpreadProfile.SerializeToString,
                response_deserializer=tarot_dot_tarot_dot_users__pb2.SpreadProfile.FromString,
                )


class UsersServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateTelegramUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTelegramUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTelegramUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSpreadProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UsersServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTelegramUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTelegramUser,
                    request_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
                    response_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
            ),
            'GetTelegramUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTelegramUser,
                    request_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUserRequest.FromString,
                    response_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
            ),
            'UpdateTelegramUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTelegramUser,
                    request_deserializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
                    response_serializer=tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
            ),
            'UpdateSpreadProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSpreadProfile,
                    request_deserializer=tarot_dot_tarot_dot_users__pb2.SpreadProfile.FromString,
                    response_serializer=tarot_dot_tarot_dot_users__pb2.SpreadProfile.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tarot.Users', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Users(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateTelegramUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/CreateTelegramUser',
            tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
            tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTelegramUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/GetTelegramUser',
            tarot_dot_tarot_dot_users__pb2.TelegramUserRequest.SerializeToString,
            tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTelegramUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/UpdateTelegramUser',
            tarot_dot_tarot_dot_users__pb2.TelegramUser.SerializeToString,
            tarot_dot_tarot_dot_users__pb2.TelegramUser.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSpreadProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.Users/UpdateSpreadProfile',
            tarot_dot_tarot_dot_users__pb2.SpreadProfile.SerializeToString,
            tarot_dot_tarot_dot_users__pb2.SpreadProfile.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
